Installation
############

We encourage to install the package via pip (or add it to your
`requirements.txt` file):


.. code-block:: console

  (.venv) pip install gurobi-modelanalyzer


.. note::

  If not already installed, this should install the :pypi:`gurobipy`
  and :pypi:`numpy``
  packages.


.. note::

  The package has been tested with and is supported for Python 3.7, 3.9
  and 3.10.

.. note::

   If for some reason you prefer not to install the package, all of the
   functionality for the ill conditioning explainer is contained in the
   source files results_analyzer.py and common.py, available in the GitHub
   repository.
